<!-- these macros are generated by "yarn build:production". do not edit by hand. -->
{% macro head_pre_icons() %}
  <link rel="stylesheet"
    href="{{ pathto('_static/vendor/fontawesome/5.13.0/css/all.min.css', 1) }}">
  <link rel="preload" as="font" type="font/woff2" crossorigin
    href="{{ pathto('_static/vendor/fontawesome/5.13.0/webfonts/fa-solid-900.woff2', 1) }}">
  <link rel="preload" as="font" type="font/woff2" crossorigin
    href="{{ pathto('_static/vendor/fontawesome/5.13.0/webfonts/fa-brands-400.woff2', 1) }}">
{% endmacro %}

{% macro head_pre_fonts() %}
{% endmacro %}

{% macro head_pre_bootstrap() %}
  <link href="{{ pathto('_static/css/theme.css', 1) }}" rel="stylesheet" />
  <link href="{{ pathto('_static/css/index.f6b7ca918bee2f46fd9abac01cfb07d5.css', 1) }}" rel="stylesheet" />
{% endmacro %}

{% macro head_js_preload() %}
  <link rel="preload" as="script" href="{{ pathto('_static/js/index.1e043a052b0af929e4d8.js', 1) }}">
{% endmacro %}

{% macro body_post() %}
  <script src="{{ pathto('_static/js/index.1e043a052b0af929e4d8.js', 1) }}"></script>
{% endmacro %}