<footer class="footer mt-5 mt-md-0">
  <div class="container">
    <p>
      {%- if show_copyright %}
        {%- if hasdoc('copyright') %}
          {% trans path=pathto('copyright'), copyright=copyright|e %}&copy; <a href="{{ path }}">Copyright</a> {{ copyright }}.{% endtrans %}<br/>
        {%- else %}
          {% trans copyright=copyright|e %}&copy; Copyright {{ copyright }}.{% endtrans %}<br/>
        {%- endif %}
      {%- endif %}
      {%- if last_updated %}
        {% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}<br/>
      {%- endif %}
      {%- if show_sphinx %}
        {% trans sphinx_version=sphinx_version|e %}Created using <a href="http://sphinx-doc.org/">Sphinx</a> {{ sphinx_version }}.{% endtrans %}<br/>
      {%- endif %}
    </p>
  </div>
</footer>